@@ -59,7 +59,41 @@ static inline void set_same_or_different(const VList *, const char *, const char
 
 #define DIR_COPY \
 {\
+	char *s = tmp_src;\
+	char *d = tmp_dst;\
+	_Bool parent_flag = false;\
+\
+	for(;;)\
+	{\
+		if(*s == *d)\
+		{\
+			if(*s == '\0')\
+			{\
+				parent_flag = true;\
+				break;\
+			}\
+\
+			s++;\
+			d++;\
+		}\
+		else if(*s == '\0')\
+		{\
+			parent_flag = true;\
+			break;\
+		}\
+		else if(*d == '\0')\
+		{\
+			break;\
+		}\
+		else \
+		{\
+			break;\
+		}\
+	}\
+\
+	/* cmpはstrcmpのcmp */\
 	_Bool cmp_flag = false;\
+\
 	if(src_current_flag == true)\
 	{\
 		char *s = cpinfo->src;\
@@ -90,7 +124,6 @@ static inline void set_same_or_different(const VList *, const char *, const char
 \
 				if(*s == '\0')\
 				{\
-\
 					if(*d == G_DIR_SEPARATOR)\
 					{\
 						cmp_flag = true;\
@@ -99,15 +132,29 @@ static inline void set_same_or_different(const VList *, const char *, const char
 				}\
 			}\
 		}\
-\
-		if(cmp_flag == true)\
-		{\
-			fprintf(stderr, ".をスキップします\n");\
-			continue;\
-		}\
 	}\
 \
-	if(cmp_flag == false)\
+	if(cmp_flag == true)\
+	{\
+		fprintf(stderr, "`.' をスキップします\n");\
+\
+		if(cpinfo->src != NULL) free(cpinfo->src);\
+		if(cpinfo->dst != NULL) free(cpinfo->dst);\
+\
+		free(cpinfo);\
+		cpinfo = NULL;\
+	}\
+	else if(parent_flag == true)\
+	{\
+		fprintf(stderr, "`%s' をスキップします\n", cpinfo->src);\
+\
+		if(cpinfo->src != NULL) free(cpinfo->src);\
+		if(cpinfo->dst != NULL) free(cpinfo->dst);\
+\
+		free(cpinfo);\
+		cpinfo = NULL;\
+	}\
+	else \
 	{\
 		set_same_or_different(drive_list, tmp_src, tmp_dst, cpinfo, oparg); \
 \
@@ -183,34 +230,42 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 	((loop_dst - loop) == 1) ? (acount = SINGULAR) : (acount = PLURAL);
 
 	/* コピー元が.でコピー先が存在しないとき用の処理 */
-	switch(acount)
+	if(acount == SINGULAR)
 	{
-	case SINGULAR:
-		{
-			char *c = oparg->argv[loop];
-			if(
-				(c[0] == '.') &&
-					(
-						(c[1] == '\0') ||
-						((c[1] == G_DIR_SEPARATOR) && (c[2] == '\0')) ||
-						((c[1] == G_DIR_SEPARATOR) && (c[2] == '.') && (c[3] == '\0'))
-					)
-			)
-			{
-				errno = 0;
+		char *c = oparg->argv[loop];
+		_Bool current_flag = true;
 
-				if(mkdir(oparg->argv[loop_dst], 0755) == -1)
+		for(;;)
+		{
+			if((*c == '.') || (*c == G_DIR_SEPARATOR))
+			{
+				c++;
+			}
+			else if(*c == '\0')
+			{
+				break;
+			}
+			else
+			{
+				current_flag = false;
+				break;
+			}
+		}
+
+		if(current_flag == true)
+		{
+			errno = 0;
+
+			if(mkdir(oparg->argv[loop_dst], 0755) == -1)
+			{
+				if((errno != EEXIST) && (errno != 0))
 				{
-					if((errno != EEXIST) && (errno != 0))
-					{
-						print_error("mkdir", __FILE__, __LINE__, cpdd);
-						fprintf(stderr, "コピー先フォルダの作成に失敗しました\n");
-						exit(EXIT_FAILURE);
-					}
+					print_error("mkdir", __FILE__, __LINE__, cpdd);
+					fprintf(stderr, "コピー先フォルダの作成に失敗しました\n");
+					exit(EXIT_FAILURE);
 				}
 			}
 		}
-		break;
 	}
 
 	errno = 0;
@@ -253,7 +308,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 		/* strcmpは等しければ0を返す */
 		if(strcmp(oparg->argv[loop], "..") == 0)
 		{
-			fprintf(stderr, "..をスキップします\n");
+			fprintf(stderr, "`..' をスキップします\n");
 			continue;
 		}
 		else if(strcmp(oparg->argv[loop], ".") == 0)
@@ -281,7 +336,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 			if(errno != 0)
 			{
 				print_error("realpath", __FILE__, __LINE__, cpdd);
-				fprintf(stderr, "%s\n", oparg->argv[loop]);
+				fprintf(stderr, "`%s'\n", oparg->argv[loop]);
 				continue;
 			}
 		}
@@ -296,8 +351,9 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 		memcpy(cpinfo->src, tmp_src, len_src);
 		len_src--;
 
-		if(file_found == true)
+		switch(file_found)
 		{
+		case true:
 			if(g_file_test(tmp_dst, G_FILE_TEST_IS_REGULAR) == TRUE)
 			{
 				len_dst++;
@@ -352,7 +408,7 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 				}
 				else
 				{
-					fprintf(stderr, "%s をスキップします\n", tmp_src);
+					fprintf(stderr, "`%s' をスキップします\n", tmp_src);
 				}
 			}
 			else
@@ -360,9 +416,9 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 				fprintf(stderr, "コピー先が不正です\n");
 				exit(EXIT_FAILURE);
 			}
-		}
-		else
-		{
+			break;
+
+		case false:
 			if(acount == PLURAL)
 			{
 				char *target;
@@ -405,8 +461,9 @@ RData * check_target(OPArg *oparg, VList *drive_list, SDir *sdir)
 			}
 			else
 			{
-				fprintf(stderr, "%s をスキップします\n", tmp_src);
+				fprintf(stderr, "`%s' をスキップします\n", tmp_src);
 			}
+			break;
 		}
 	}
 
@@ -564,7 +621,7 @@ INPUT:
 			switch(iowt)
 			{
 			case INFO:
-				printf("%sは既に存在します。\n", cpinfo->dst);
+				printf("`%s' は既に存在します。\n", cpinfo->dst);
 				puts("上書きしますか? (y: Yes  a: 全てYes  d: このフォルダのみYes  n: No  o: このフォルダのみNo  z: 全てNo)");
 				printf(" : ");
 
@@ -707,7 +764,7 @@ struct stat * make_directory(CPInfo *cpinfo, OPArg *oparg, CPDD *cpdd)
 	{
 		if(oparg->V == VERBOS)
 		{
-			printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
+			printf("`%s' -> `%s'\n", cpinfo->src, cpinfo->dst);
 			fflush(stdout);
 		}
 
@@ -838,7 +895,7 @@ static VList * dir_traverse(VList *file_list, CPInfo *cpinfo_tmp, OPArg *oparg,
 	else
 	{
 		print_error("opendir", __FILE__, __LINE__, cpdd);
-		fprintf(stderr, "%s を読み取れませんでした\n", src_dir);
+		fprintf(stderr, "`%s' を読み取れませんでした\n", src_dir);
 	}
 
 	return file_list;
@@ -1077,9 +1134,7 @@ static inline void set_same_or_different(const VList *drive_list, const char *sr
 	for(;;)
 	{
 		DPath *tmp = (DPath *)tmplist->data;
-/*
-printf("%s %s\n", tmp->device, tmp->mount_point);
-*/
+
 		if((tmp->mount_point[1] == '\0') && (tmp->mount_point[0] == G_DIR_SEPARATOR))
 		{
 			if(srcdev == NULL)
