@@ -129,7 +129,7 @@ static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 	}
 	else
 	{
-		printf("%s をスキップします\n", cpinfo->dst);
+		printf("`%s' をスキップします\n", cpinfo->dst);
 		fflush(stdout);
 		check = false;
 	}
@@ -183,7 +183,7 @@ static inline _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd)
 
 			if(oparg->V == VERBOS)
 			{
-				printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
+				printf("`%s' -> `%s'\n", cpinfo->src, cpinfo->dst);
 				fflush(stdout);
 			}
 
