@@ -323,7 +323,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 		else
 		{
 			print_error("NODATA", __FILE__, __LINE__, cpdd);
-			fprintf(stderr, "%s をコピーできません\n", cpinfo->src);
+			fprintf(stderr, "`%s' をコピーできません\n", cpinfo->src);
 		}
 	}
 
@@ -382,7 +382,7 @@ void read_write(const OPArg *oparg, const SDir *sdir, CPInfo *cpinfo, CPDD *cpdd
 
 		if(oparg->V == VERBOS)
 		{
-			printf("%s -> %s\n", cpinfo->src, cpinfo->dst);
+			printf("`%s' -> `%s'\n", cpinfo->src, cpinfo->dst);
 			fflush(stdout);
 		}
 
