@@ -114,25 +114,21 @@ int main(int argc, char **argv)
 
 	puts("");
 
-	if(cpdd->thread_mode_count > 0)
+	if(cpdd->file_count > 0)
 	{
-		printf("File   : %lld / %lld (Thread : %lld / %lld)\n", cpdd->mk_file_count, cpdd->file_count, cpdd->thread_mode_count, cpdd->mk_file_count);
-	}
-	else
-	{
-		printf("File   : %lld / %lld\n", cpdd->mk_file_count, cpdd->file_count);
-	}
-	printf("Link   : %lld / %lld\n", cpdd->mk_link_count, cpdd->link_count);
-	printf("Dir    : %lld / %lld\n", cpdd->mk_dir_count, cpdd->dir_count);
-	printf("Source : %lld MB (%lld Bytes)\n", cpdd->total_source / (1024 * 1024), cpdd->total_source);
-	printf("Read   : %lld MB (%lld Bytes)\n", cpdd->total_read / (1024 * 1024), cpdd->total_read);
-	printf("Write  : %lld MB (%lld Bytes)\n", cpdd->total_write / (1024 * 1024), cpdd->total_write);
+		printf("File   : %lld / %lld", cpdd->mk_file_count, cpdd->file_count);
 
-	if(cpdd->total_error > 0)
-	{
-		printf("Error  : %lld\n", cpdd->total_error);
+		if(cpdd->thread_mode_count > 0) { printf(" (Thread : %lld / %lld)\n", cpdd->thread_mode_count, cpdd->mk_file_count); }
+		else { puts(""); }
 	}
 
+	if(cpdd->link_count > 0)   { printf("Link   : %lld / %lld\n", cpdd->mk_link_count, cpdd->link_count); }
+	if(cpdd->dir_count > 0)    { printf("Dir    : %lld / %lld\n", cpdd->mk_dir_count, cpdd->dir_count); }
+	if(cpdd->total_source > 0) { printf("Source : %lld MB (%lld Bytes)\n", cpdd->total_source / (1024 * 1024), cpdd->total_source); }
+	if(cpdd->total_read > 0)   { printf("Read   : %lld MB (%lld Bytes)\n", cpdd->total_read / (1024 * 1024), cpdd->total_read); }
+	if(cpdd->total_write > 0)  { printf("Write  : %lld MB (%lld Bytes)\n", cpdd->total_write / (1024 * 1024), cpdd->total_write); }
+	if(cpdd->total_error > 0)  { printf("Error  : %lld\n", cpdd->total_error); }
+
 	/*
 	 * close()する必要があるもの
 	 * sdir->current_fd
@@ -155,7 +151,7 @@ int main(int argc, char **argv)
 		if(errno != ENOENT)\
 		{\
 			print_error("unlink", __FILE__, __LINE__, cpdd);\
-			fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->src);\
+			fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->src);\
 		}\
 	}\
 \
@@ -263,7 +259,7 @@ static inline void delete_src(const OPArg *oparg, const VList *file_list, CPDD *
 				if((errno != ENOTEMPTY) && (errno != ENOENT))
 				{
 					print_error("remove", __FILE__, __LINE__, cpdd);
-					fprintf(stderr, "%s の削除に失敗しました\n", cpinfo->src);
+					fprintf(stderr, "`%s' の削除に失敗しました\n", cpinfo->src);
 				}
 			}
 			break;
