@@ -13,11 +13,11 @@
 #include <sys/stat.h>
 
 /* 関数プロトタイプ */
-static inline void write_log_hash_check(const CPInfo *cpinfo, const char *from_hash, const char *to_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success) __attribute__((always_inline));
+static inline void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success) __attribute__((always_inline));
 static inline void set_today(char *today) __attribute__((always_inline));
 static inline void set_time_now(char *hms) __attribute__((always_inline));
 
-static inline void write_log_hash_check(const CPInfo *cpinfo, const char *from_hash, const char *to_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success)
+static inline void write_log_hash_check(const CPInfo *cpinfo, const char *src_hash, const char *dst_hash, const SDir *sdir, CPDD *cpdd, _Bool c_success)
 {
 	/* ログを保存するフォルダが存在しない場合は作成する */
 	if(g_file_test(sdir->config_dir, G_FILE_TEST_EXISTS) == FALSE)
@@ -77,13 +77,13 @@ static inline void write_log_hash_check(const CPInfo *cpinfo, const char *from_h
 		if(
 			(fputs(hms, log) != EOF) &&
 			(fputs("\n", log) != EOF) &&
-			(fputs(from_hash, log) != EOF) &&
+			(fputs(src_hash, log) != EOF) &&
 			(fputs(",", log) != EOF) &&
-			(fputs(cpinfo->from, log) != EOF) &&
+			(fputs(cpinfo->src, log) != EOF) &&
 			(fputs("\n", log) != EOF) &&
-			(fputs(to_hash, log) != EOF) &&
+			(fputs(dst_hash, log) != EOF) &&
 			(fputs(",", log) != EOF) &&
-			(fputs(cpinfo->to, log) != EOF) &&
+			(fputs(cpinfo->dst, log) != EOF) &&
 			(fputs("\n", log) != EOF)
 		)
 		{
